//
// TestSevenSegment.cxx Thu Feb 2 2006 z_hossain
//
// Test of seven segment widget for the Fast Light Tool Kit (FLTK).
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//


#include <fltk/Window.h>
#include <fltk/Input.h>
#include <fltk/Slider.h>
#include <fltk/run.h>

#include <stdio.h>

#include "SevenSegment.h"

using namespace fltk;

Input *txt_value = 0;
Slider *sl_thick = 0;
Slider *sl_value = 0;
Slider *sl_gap = 0;
Slider *sl_col = 0;
SevenSegment *seg_big = 0;
SevenSegment *seg_small = 0;
Window* make_window();

static int COLOR[] = {
	56, 88, 63, 95, 216, 248, 223, 72
};

static void cb_txt_value(Input* in, void*) {
	seg_small->value(in->value());
	in->value(seg_small->value());//get what is actual
}

static void cb_sl_thick(Slider*, void*) {
	seg_big->thickness((int)sl_thick->value());
	seg_big->redraw();
}

static void cb_sl_value(Slider*, void*) {
	static char buf[10];
	sprintf(buf, "%d", (int)sl_value->value());
	seg_big->value(buf);
}

static void cb_sl_gap(Slider*, void*) {
	seg_big->segment_gap((int)sl_gap->value());
	seg_big->redraw();
}

static void cb_sl_col(Slider*, void*) {
	seg_big->textcolor((Color)COLOR[int(sl_col->value())]);
	seg_big->redraw();
}

int main(int ac,char **av) {
	Window* w;
	{ Window* o = new Window(450, 305);
		w = o;
		w->begin();
		{ SevenSegment* o = seg_big = new SevenSegment(20, 25, 255, 267);
			//o->box(NO_BOX);	
			//o->deactivate(); 															//support activate/deactivate
		}
		{ SevenSegment* o = seg_small = new SevenSegment(285, 25, 135, 35);
			//o->dot_len(o->unit_h() / 5.0);
		}
		{ Input* o = txt_value = new Input(285, 90, 135, 25, "Any Dec/Hex Value");
			o->callback((Callback*)cb_txt_value);
			o->align(ALIGN_TOPLEFT);
			o->when(WHEN_ENTER_KEY);
		}
		{ Slider* o = sl_thick = new Slider(335, 132, 25, 158);
			o->textsize(8);
			o->range(2, 40);
			o->step(1);
			o->type(Slider::TICK_ABOVE);
			o->value(seg_big->thickness());
			o->callback((Callback*)cb_sl_thick);
			o->set_vertical();
		}
		{ Slider* o = sl_value = new Slider(295, 133, 25, 157);
			o->step(0.01);
			o->textsize(8);
			o->range(0, 9);
			o->step(1);
			o->value(0);
			cb_sl_value(o, NULL);
			o->callback((Callback*)cb_sl_value);
			o->set_vertical();
			o->type(Slider::TICK_ABOVE);
		}
		{ Slider* o = sl_gap = new Slider(375, 132, 25, 158);
			o->textsize(8);
			o->range(0, 20);
			o->step(1);
			o->value(seg_big->segment_gap());
			o->callback((Callback*)cb_sl_gap);
			o->set_vertical();
			o->type(Slider::TICK_ABOVE);
		}
		{ Slider* o = sl_col = new Slider(410, 132, 25, 158);
			o->textsize(8);
			o->range(0, 7);
			o->step(1);
			o->value(0);
			o->callback((Callback*)cb_sl_col);
			o->set_vertical();
			o->type(Slider::TICK_ABOVE);
		}
		o->show(ac, av);
		o->end();
	}
	return run();
}
